@@ -291,7 +291,7 @@ def decodeUpdatePoolPair(hex):
         {'bytesCount':1, 'key': 'tokenId', 'type': int,'endian':None, 'canExceedBytesCount': True},
         {'bytesCount':4, 'key': 'status', 'type': int,'endian':None},
         {'bytesCount': 8, 'key': 'commission', 'type': int,'endian':'little'},
-        {'bytesCount': 'rest', 'key': 'rest', 'type': str,'endian':None}
+        {'bytesCount': 'rest', 'key': 'rest', 'type': 'hex','endian':None}
     ]
     return searchHex(variables,hex)
 def decodeAccountToAccount(hex):
